pub struct BlockPos {
pub x: i32,
pub y: i32,
pub z: i32,
}Expand description
Represents an absolute block position in world space.
Fields
x: i32y: i32z: i32Implementations
Sourceimpl BlockPos
impl BlockPos
Sourcepub const fn get_in_direction(self, dir: Direction) -> Self
pub const fn get_in_direction(self, dir: Direction) -> Self
Get a new BlockPos that is adjacent to this position in dir
direction.
use chunkedge_protocol::{BlockPos, Direction};
let pos = BlockPos::new(0, 0, 0);
let adj = pos.get_in_direction(Direction::South);
assert_eq!(adj, BlockPos::new(0, 0, 1));Sourcepub const fn to_center_dvec3(self) -> DVec3
pub const fn to_center_dvec3(self) -> DVec3
Get the center of a block position by adding 0.5 to each axis.
Sourcepub const fn to_bottom_center_dvec3(self) -> DVec3
pub const fn to_bottom_center_dvec3(self) -> DVec3
Get the bottom center of a block position by adding 0.5 to the x and z axes.
pub const fn offset(self, x: i32, y: i32, z: i32) -> Self
pub const fn packed(self) -> Result<PackedBlockPos, Error>